##############################################################################
#
#    Copyright (C) 2010 Yannick Soldati. All Rights Reserved
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

import wizard
import pooler


class BOMSearchProduct(wizard.interface):

    def _search(self, cursor, user, data, context=None):
        pool = pooler.get_pool(cursor.dbname)
        model_data_obj = pool.get('ir.model.data')
        act_window_obj = pool.get('ir.actions.act_window')
        bom_obj = pool.get('mrp.bom')

        model_data_id = model_data_obj._get_id(cursor, user, 'mrp',
                'mrp_bom_form_action')
        model_data = model_data_obj.browse(cursor, user, model_data_id,
                context=context)
        result = act_window_obj.read(cursor, user, model_data.res_id,
                context=context)

        product_id = data['form']['product']

        bom_lines_ids = bom_obj.search(cursor, user, [
            ('bom_id', '!=', False),
            ('product_id', '=', product_id),
            ], context=context)
        bom_lines = bom_obj.browse(cursor, user, bom_lines_ids,
                context=context)
        domain = [
            ('id', 'in', [bom_line.bom_id.id for bom_line in bom_lines]),
        ]
        result['domain'] = str(domain)
        return result

    states = {
        'init': {
            'result': {
                'type': 'form',
                'arch': '''<?xml version="1.0"?>
<form string="Select Product Line">
    <field name="product"/>
</form>''',
                'fields': {
                    'product': {
                        'type': 'many2one',
                        'relation': 'product.product',
                        'string': 'Product Line',
                        'required': True,
                    },
                },
                'state': [
                    ('end', 'Cancel', 'gtk-cancel'),
                    ('search', 'Search', 'gtk-ok', True),
                ],
            },
        },
        'search': {
            'result': {
                'type': 'action',
                'action': _search,
                'state': 'end',
            },
        },
    }

BOMSearchProduct('bom_search_product')
